# N.B.: this could be a GIT hash as well.
%global commit 0.1

Name:           dwgrep
Version:        0.1
Release:        1%{?dist}
Summary:        A tool for querying Dwarf (debuginfo) graphs
Group:          Development/Tools

License:        GPLv3+ and (GPLv2+ or LGPLv3+)
URL:            http://pmachata.github.io/dwgrep/index.html
Source0:        https://github.com/pmachata/dwgrep/archive/%{commit}/dwgrep-%{commit}.tar.gz

BuildRequires:  elfutils-devel python-sphinx gtest-devel

%description

Dwgrep is a tool, an associated language (called Zwerg) and a library
(libzwerg) for querying Dwarf (debuginfo) graphs.

You can think of dwgrep expressions as instructions describing a path
through a graph, with assertions about the type of nodes along the
way: that a node is of given type, that it has a given attribute,
etc. There are also means of expressing sub-conditions,
i.e. assertions that a given node is acceptable if a separate
expression matches (or does not match) a different path through the
graph.


%package libzwerg
Summary:        Library for querying Dwarf (debuginfo) graphs
Group:          Development/Libraries

%description libzwerg

Libzwerg contains implementation of the Zwerg query engine as well as
individual words of both Core and Dwarf vocabularies.

%post libzwerg -p /sbin/ldconfig

%postun libzwerg -p /sbin/ldconfig


%package libzwerg-devel
Summary:        Headers and shared development libraries for libzwerg
Group:          Development/Libraries
Requires:       dwgrep-libzwerg%{?_isa} = %{version}-%{release}
Requires:       elfutils-devel%{?_isa} = %{version}-%{release}

%description libzwerg-devel
Headers and shared object symbolic links for the Boost C++ libraries.


%package doc
Summary:        HTML documentation for dwgrep and libzwerg
Group:          Documentation
BuildArch:      noarch

%description doc

This package contains dwgrep-related documentation in the HTML
format. The documentation provides the same content as that on the
Boost web page (http://pmachata.github.io/dwgrep/).


%prep
%setup -q -n dwgrep-%{commit}


%build
mkdir build
pushd build
%cmake ..
make %{?_smp_mflags}
make doc %{?_smp_mflags}
popd


%install
rm -rf $RPM_BUILD_ROOT
pushd build
make install DESTDIR=$RPM_BUILD_ROOT
popd


%check
pushd build
make test
popd


%files
%defattr(-, root, root, -)
%doc NEWS README
# N.B.: COPYING* brought in by the (implicit) libzwerg dependency.
%{_bindir}/dwgrep
%{_mandir}/man1/dwgrep.1*

%files libzwerg
%defattr(-, root, root, -)
%doc COPYING COPYING-LGPLV3
%{_libdir}/libzwerg.so.0.1

%files libzwerg-devel
%defattr(-, root, root, -)
# N.B.: COPYING* brought in by the libzwerg dependency.
%{_includedir}/libzwerg/libzwerg.h
%{_includedir}/libzwerg/libzwerg-dw.h
%{_libdir}/libzwerg.so

%files doc
%defattr(-, root, root, -)
%doc build/doc/html/*


%changelog
* Mon Dec  8 2014 Petr Machata <pmachata@redhat.com> - 0.1-1
- Initial package.
